import request from "../utils/request"

// -----------------------------财务列表
 /**
  * 获取简易的套餐列表（用于搜索下拉框）
 * @returns 
 */
export function getSimpleServiceList() {
 return request({
     url:'/contract/service/simple',
     method:'get'
 })
}

 // 获取套餐列表
 /**
  * 
  * @param {
  * product_id - 套餐类型: 1-FICC(默认); 2-权益 - 非必填
  * } data 
  * @returns 
  */
export function getServiceList(data) {
  return request({
      url:'/contract/service/list',
      method:'get',
      params:data
  })
}
// 获取财务列表
 /**
  * 
  * @param {
  * page_size - 每页数据量 - 必填
  * current - 页码 - 必填
  * keyword - 关键词-合同编号/客户姓名/销售姓名 - 非必填
  * start_date - 合同创建日期开始：格式2022-11-22 - 非必填
  * end_date - 合同创建日期结束：格式2022-11-22 - 非必填
  * service_type - 套餐ID - 非必填
  * contract_type - 合同类型：1-新签; 2-续约 - 非必填
  * register_status - 登记状态：1-进行中; 2-已完成 - 非必填
  * } data 
  * @returns 
  */
export function getRegisterList(data) {
  return request({
      url:'/contract/register/list',
      method:'get',
      params:data
  })
}
// 获取导出财务列表
export function registerListExport(data) {
  return request({
      url:'/contract/register/export',
      method:'get',
      params:data,
      responseType:'blob'
  })
}

 /**
  * 客户名称或者合同有效期查询校验
  * @param {
 * company_name - 客户名称 - 必填
 * start_date - 开始日期：格式2022-11-22 - 必填
 * end_date - 开始日期：格式2022-11-22 - 必填
 * } data 
 * @returns 
 */
export function contractRegisterCheck(data) {
 return request({
     url:'/contract/register/check_contract_code',
     method:'get',
     params:data
 })
}
// 合规登记 - 新增
 /**
  * 
  * @param {
  * 太多了，看代码
  * } data 
  * @returns 
  */
export function registerAdd(data) {
  return request({
      url:'/contract/register/add',
      method:'post',
      data
  })
}
// 合规登记 - 编辑
 /**
  * 
  * @param {
  * 太多了，看代码
  * } data 
  * @returns 
  */
export function registerEdit(data) {
  return request({
      url:'/contract/register/edit',
      method:'post',
      data
  })
}
// 开票登记
export function registerInvoice(data) {
  return request({
      url:'/contract/register/invoice',
      method:'post',
      data
  })
}
// 到款登记
export function registerPayment(data) {
  return request({
      url:'/contract/register/payment',
      method:'post',
      data
  })
}
// 获取财务详情
 /**
  * 
  * @param {
  * contract_register_id - 合同登记ID - 必填
  * } data 
  * @returns 
  */
export function registerDetail(data) {
  return request({
      url:'/contract/register/detail',
      method:'get',
      params:data
  })
}

// 更改合同状态
 /**
  * 
  * @param {
  * contract_register_id - 合同登记ID - 必填
  * contract_status - 合同状态: 1-已审批; 2-单章寄出; 3-已签回 4-已终止 - 必填
  * } data 
  * @returns 
  */
export function updateRegisterStatus(data) {
  return request({
      url:'/contract/register/update_status',
      method:'post',
      data
  })
}

// 删除合规
 /**
  * 
  * @param {
  * contract_register_id - 合同登记ID - 必填
  * } data 
  * @returns 
  */
export function registerDelete(data) {
  return request({
      url:'/contract/register/del',
      method:'post',
      data
  })
}

// 开票、到款列表
//获取列表
 /**
  * 
  * @param {
 * page_size - 每页数据量 - 必填
 * current - 页码 - 必填
 * contract_code - 关键词-合同编号 - 非必填
 * start_date - 开始日期：格式2022-11-22 - 非必填
 * end_date - 结束日期：格式2022-11-22 - 非必填
 * min_amount - 开票金额区间-最小值 - 非必填
 * max_amount - 开票金额区间-最大值 - 非必填
 * invoice_type - 类型: 1-开票登记; 2-到款登记 - 必填
 * is_export - 是否是导出：0-否 1-是
 * } data 
 * @returns 
 */
export function getIandPList(data) {
 return request({
    url:'/contract/register/invoice_list',
    method:'get',
    params:data,
    responseType:data.is_export==1?'blob':'text'
 })
}

// 合规登记-导入
 /**
  * 
  * @param {
 * File - 文件formData - 必填
 * } data 
 * @returns 
 */
export function importDataApi(data) {
 return request({
     url:'/contract/register/import',
     method:'post',
     data
 })
}
// -----------------到款预登记
// 获取到款预登记列表
 /**
  * 
  * @param {
 * page_size - 每页数据量 - 必填
 * current - 页码 - 必填
 * Keyword - 关键词-客户姓名/销售姓名 - 非必填
 * StartDate - 约定开始时间：格式2022-11-22 - 非必填
 * EndDate - 约定结束时间：格式2022-11-22 - 非必填
 * SortType - 枚举值：asc 正序 desc 倒序 - 非必填
 * } data 
 * @returns 
 */
export function getPrePlacementList(data) {
 return request({
     url:'/contract/pre_pay/list',
     method:'get',
     params:data
 })
}

// 新增到款预登记
 /**
  * @param data.company_name 客户名称 
  * @param data.seller_id 销售ID 
  * @param data.seller_name 销售姓名 
  * @param data.amount 到款金额 
  * @param data.currency_unit 货币代码 
  * @param data.start_date 约定开始日期 
  * @param data.end_date 约定结束日期 
  * @param data.remark 备注 
 * @returns 
 */
export function prePlacementAdd(data) {
 return request({
     url:'/contract/pre_pay/add',
     method:'post',
     data
 })
}

// 编辑到款预登记
 /**
  * @param data.pre_pay_id 到款预登记Id 
  * @param data.company_name 客户名称 
  * @param data.seller_id 销售ID 
  * @param data.seller_name 销售姓名 
  * @param data.amount 到款金额 
  * @param data.currency_unit 货币代码 
  * @param data.start_date 约定开始日期 
  * @param data.end_date 约定结束日期 
  * @param data.remark 备注 
 * @returns 
 */
 export function prePlacementEdit(data) {
  return request({
      url:'/contract/pre_pay/edit',
      method:'post',
      data
  })
 }

 // 删除到款预登记
 /**
  * 
  * @param {
 * pre_pay_id - 到款预登记ID - 必填
 * } data 
 * @returns 
 */
export function prePlacementDelete(data) {
 return request({
     url:'/contract/pre_pay/del',
     method:'post',
     data
 })
}
// -----------------预登记
// 获取预登记列表
 /**
  * 
  * @param data.page_size - 每页数据量 - 必填
  * @param data.current - 页码 - 必填
  * @param data.keyword - 关键词-客户姓名 - 非必填
 * @returns 
 */
export function getPreRegistrationList(data) {
  return request({
      url:'/contract/pre_register/list',
      method:'get',
      params:data
  })
}
 /**
  * 新增预登记时 判断合规信息是否存在
  * @param {
 * company_name - 客户名称
 * start_date - 约定开始日期
 * end_date - 约定结束日期
 * services - 套餐列表
 * contract_type 1-新签 2-续约 4-补充
 * has_payment 0-指自付 1-代付
 * } data 
 * @returns 
 */
export function preRegistrationCheck(data) {
 return request({
     url:'/contract/register/check_contract_duplicate',
     method:'post',
     data
 })
}
 // 新增预登记
 /**
  * 
  * @param {
 * contract_register_id - 到登记ID
 * company_name - 客户名称
 * register_type - 预登记类型 3-开票预登记 4-到款预登记 
 * start_date - 约定开始日期
 * end_date - 约定结束日期
 * lists - 开票/到款列表 
 * services - 套餐列表
 * } data 
 * @returns 
 */
export function preRegistrationAdd(data) {
 return request({
     url:'/contract/pre_register/add',
     method:'post',
     data
 })
}
 // 预登记详情
 /**
  * 
  * @param {
 * invoice_id
 * contract_register_id 
 * detail_type(1编辑 2预开票/到款)
 * contract_type 1-新签 2-续约 4-补充
 * has_payment 0-指自付 1-代付
 * } data 
 * @returns 
 */
export function preRegistrationDetail(data) {
 return request({
     url:'/contract/pre_register/detail',
     method:'post',
     data
 })
}
 // 编辑预登记
 /**
  * 
  * @param {
 * contract_register_id - 到登记ID
 * company_name - 客户名称
 * register_type - 预登记类型 3-开票预登记 4-到款预登记 
 * start_date - 约定开始日期
 * end_date - 约定结束日期
 * lists - 开票/到款列表 
 * services - 套餐列表
 * } data 
 * @returns 
 */
export function preRegistrationEdit(data) {
 return request({
     url:'/contract/pre_register/edit',
     method:'post',
     data
 })
}
 // 预开票/预到款保存
 /**
  * 
  * @param {
 * contract_register_id - 到登记ID
 * company_name - 客户名称
 * register_type - 预登记类型 3-开票预登记 4-到款预登记 
 * start_date - 约定开始日期
 * end_date - 约定结束日期
 * lists - 开票/到款列表 
 * services - 套餐列表
 * } data 
 * @returns 
 */
export function preRegistrationSave(data) {
 return request({
     url:'/contract/pre_register/save',
     method:'post',
     data
 })
}
 // 删除预登记
 /**
  * 
  * @param {
 * invoice_id contract_register_id arrive_id pre_register_id
 * } data 
 * @returns 
 */
export function preRegistrationDelete(data) {
 return request({
     url:'/contract/pre_register/del',
     method:'post',
     data
 })
}
