import request from "../utils/request"

// -------------------财务统计-销售统计
 // 获取销售组排名列表
 /**
 * data
 * @param data.start_date - 开始日期
 * @param data.end_date - 结束日期
 * @param data.sort_field - 排序字段: 1-开票金额; 2-组别占比
 * @param data.sort_type - 排序方式: 1-正序; 2-倒序
 * @param data.is_export - 是否是导出：0-否；1-是
 * @returns 
 */
export function getSellerGroupStatisticsList(data) {
 return request({
     url:'/census/seller/group_invoice_list',
     method:'get',
     params:data,
     responseType:data.is_export==1?'blob':'text',
 })
}

  // 获取销售排名列表
 /**
 * data
 * @param data.page_size - 每页数据量 - 必填
 * @param data.current - 页码 - 必填
 * @param data.group_id - 组别ID
 * @param data.start_date - 开始日期
 * @param data.end_date - 结束日期
 * @param data.sort_field - 排序字段: 1-开票金额; 2-组别占比
 * @param data.sort_type - 排序方式: 1-正序; 2-倒序
 * @param data.is_export - 是否是导出：0-否；1-是
 * @returns 
 */
export function getSellerStatisticsList(data) {
  return request({
      url:'/census/seller/invoice_list',
      method:'get',
      params:data,
      responseType:data.is_export==1?'blob':'text',
  })
 }

// -------------------财务统计-商品到款统计
  // 获取到款统计列表
 /**
 * data
 * @param data.page_size - 每页数据量 - 必填
 * @param data.current - 页码 - 必填
 * @param data.keyword - 关键词-客户名称/销售
 * @param data.sell_group_id - 销售组别ID
 * @param data.service_type - 套餐类型
 * @param data.start_date - 开始时间
 * @param data.end_date - 结束时间
 * @param data.time_type - 时间类型：1-开票时间; 2-到款时间
 * @param data.has_invoice - 是否开票：1-已开票
 * @param data.has_payment - 是否到款：1-已到款
 * @param data.is_export - 是否是导出：0-否；1-是
 * @returns 
 */
 export function getInvoicePaymentList(data) {
  return request({
      url:'/census/invoice_payment/list',
      method:'get',
      params:data,
      responseType:data.is_export==1?'blob':'text',
  })
 }

 // 编辑付款方式
 /**
 * @param data.contract_payment_id - 到款ID（即列表中的payment_id）
 * @param data.pay_type - 付款方式: 1-年付; 2-半年付; 3-季付; 4-次付
 * @returns 
 */
export function updatePayType(data) {
 return request({
     url:'/contract/payment/update_pay_type',
     method:'post',
     data
 })
}

 // 分配套餐金额
 /**
 * @param data.contract_payment_id - 到款ID（即列表中的payment_id）
 * @param data.contract_register_id - 合同登记ID
 * @param data.contract_register_id - 合同登记ID
 * @param data.list[i].contract_payment_service_amount_id - 套餐分配ID
 * @param data.list[i].service_template_id - 套餐ID
 * @param data.list[i].amount - 套餐金额
 */
export function setServiceAmount(data) {
    return request({
        url:'/contract/payment/distribute_service_amount',
        method:'post',
        data
    })
}

// 业务收入金额统计
 /**
 * 获取业务收入金额
 * @param data.start_date - 开始时间
 * @param data.end_date - 结束时间
 * @param data.is_export - 是否是导出 0-否 1-是
 * @param data.list_param - 统计类型: 0-月度; 1-季度; 2-半年度；3-年度；4-月度累计
 * @param data.company_type - 客户类型 0全部 1新客户 2老客户
 * @param data.seller_ids - 销售ids
 * @returns 
 */
 export function getIncomeChartData(data) {
    return request({
        url:'/census/invoice_payment/income/list',
        method:'get',
        params:data,
        responseType:data.is_export==1?'blob':'text',
    })
   }
// 未开票统计
 /**
 * 未开票统计列表
 * @param data.page_size - 每页数据量 - 必填
 * @param data.current - 页码 - 必填
 * @param data.keyword - 关键词-客户名称/销售
 * @param data.seller_ids - 销售ID
 * @param data.service_type - 套餐类型
 * @param data.sort_param - 'start_date':开票日 、 'end_date':到款日
 * @param data.sort_type - asc 正序,desc 倒叙
 * @param data.is_export - 是否是导出：0-否；1-是
 * @returns 
 */
export function getWaitInvoiceList(data) {
    return request({
        url:'/census/invoice_payment/not_invoice/list',
        method:'get',
        params:data,
        responseType:data.is_export==1?'blob':'text',
    })
}
// 开票未到款统计
 /**
 * 开票未到款统计列表
 * @param data.page_size - 每页数据量 - 必填
 * @param data.current - 页码 - 必填
 * @param data.keyword - 关键词-客户名称/销售
 * @param data.seller_ids - 销售ID
 * @param data.service_type - 套餐类型
 * @param data.sort_param - 'invoice_time':开票日
 * @param data.sort_type - asc 正序,desc 倒叙
 * @param data.is_export - 是否是导出：0-否；1-是
 * @returns 
 */
 export function getWaitPaymentList(data) {
    return request({
        url:'/census/invoice_payment/not_payment/list',
        method:'get',
        params:data,
        responseType:data.is_export==1?'blob':'text',
    })
}
