
// 根据字节流下载文件
/**
 * @param {Blob} data 流数据
 * @param {String} type 下载的文件类型
 * @param {String} fileName 下载的文件名
 */
export function downloadByFlow(data,type,fileName) {
  let fileTypeMime ='application/vnd.openxmlformats-officedocument.spreadsheetml.sheet'
  switch (type) { // 获取后缀对应的 mimeType
    case 'png': fileTypeMime = 'image/png'; break;
    case 'doc': fileTypeMime = 'application/msword'; break;
    case 'docx': fileTypeMime = 'application/vnd.openxmlformats-officedocument.wordprocessingml.document'; break;
    case 'jpg': case 'jpeg': fileTypeMime = 'image/jpeg'; break;
    case 'gif': fileTypeMime = 'image/gif'; break;
    case 'svg': fileTypeMime = 'image/svg+xml'; break;
    case 'tif': case 'tiff': fileTypeMime = 'image/tiff'; break;
    case 'txt': fileTypeMime = 'text/plain'; break;
    case 'ppt': fileTypeMime = 'application/vnd.ms-powerpoint'; break;
    case 'pptx': fileTypeMime = 'application/vnd.openxmlformats-officedocument.presentationml.presentation'; break;
    case 'xls': fileTypeMime = 'application/vnd.ms-excel'; break;
    case 'xlsx': fileTypeMime = 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet'; break;
    case 'zip': fileTypeMime = 'application/zip'; break;
    case '7z': fileTypeMime = 'application/x-7z-compressed'; break;
  }
  let blob = window.URL.createObjectURL(new Blob([data], {
    'type': fileTypeMime
  }))
  let link = document.createElement('a')
  link.style.display = 'none'
  link.href = blob
  link.setAttribute('download', fileName.indexOf('.')?fileName:`${fileName}.${type}`)
  document.body.appendChild(link)
  link.click()
  document.body.removeChild(link) //下载完成移除元素
  window.URL.revokeObjectURL(blob) //释放掉 blob 对象
}

/**
 * 定时器轮询数据请求
 * @param {*} flag 调用callback标志，建议传入返回Boolean值的函数
 * @param {*} callback 回调函数
 * @param {*} timeout 轮询间隔
 */
export function intervalDataRequest(flag,callback,timeout){
  if(flag()){
    // 拿到货币列表后才去取单位
    callback()
  }else{
    // 轮询等拿到货币列表后去取单位，并清除轮询定时器
    const timer = setInterval(()=>{
      if(flag()){
        callback()
        clearInterval(timer)
      }
    },timeout)
  }
}

/**
 * 金额格式化，保留小数
 * @param {*} money 金额
 * @param {*} digit 保留几位小数- int
 * @returns momey-string
 */
export const moneyFormatter=(money,digit=2)=>{
  let digitD = parseInt(digit)
  let result=money+''
  if(!digitD && digitD!=0){
    console.error('参数错误，digit必须为整数');
    return result
  }
  if(result.indexOf('.')==-1){
    // 没有小数
    return digitD==0?result:result+'.'+'0'.padEnd(digitD,'0')
  }else{
    let digitZeno = Math.round(money)+''
    let arr = result.split('.')
    return digitD==0?digitZeno:arr[0]+'.'+arr[1].padEnd(2,'0')
  }
}