
import {useRouter} from 'vue-router'
import {getIandPList} from '@/api/financialMana'
import { downloadByFlow } from '@/utils/common-methods'
export default function getIandPListCom(type) {
  const moment = inject('$moment')
  const router = useRouter()

  const dateButtonData=[{text:'本月',tabId:1},{text:'上月',tabId:2},{text:'前月',tabId:3}]

  const serviceTypeArray=[{label:'FICC套餐',value:1},{label:'权益套餐',value:2}]

  const placement=reactive({
    searchParams:{
      current:1,
      page_size:10,
      keyword:'',
      start_date:'',
      end_date:'',
      min_amount:'',
      max_amount:'',
      invoice_type:type,
      seller_ids:'',
      service_product_id:'',
      is_export:0
    },
    dateRange:[],
    tableData:[],
    total:0,
    amountTotal:0,
    countryAmountList:[],
    currentDateTab:0
  })


  watch(()=>placement.dateRange,(newVal)=>{
    if(newVal && newVal.length>0){
      placement.searchParams.start_date=newVal[0]
      placement.searchParams.end_date=newVal[1]
    }else{
      placement.searchParams.start_date=placement.searchParams.end_date=''
    }
    searchPlacement()
  })

  const placementList=()=>{
    getIandPList(placement.searchParams).then(res=>{
      placement.tableData=res.data.list || []
      placement.total=res.data.page&&res.data.page.total || 0
      placement.amountTotal = res.data.amount_total || 0
      placement.countryAmountList=res.data.currency_total||[]
    })
  }
  
  const searchPlacement=()=>{
    placement.searchParams.current = 1
    placementList()
  }

  const sellerChange=(value)=>{
    placement.searchParams.seller_ids = value.join(',')
    searchPlacement()
  }

  // 搜索项-开始金额和结束金额改变
  const moneyChange=(value,prop)=>{
    let trimValue = value.trim()
    let numerValue=parseFloat(trimValue)
    // 如果输入不是 以.结尾&&只有一个. 或者 不是零结尾的话，就赋值为转为成数字后的值
    // 考虑到类似12.02的情况
    if((value.endsWith('.') && value.indexOf('.')==(value.length-1)) || 
    (value.endsWith('0') && value.indexOf('.')==(value.length-2))){
      return
    }
    if((!numerValue)&&trimValue&&numerValue!=0){
      setTimeout(()=>{
        placement.searchParams[prop]=''
      },500)
      ElMessage.warning('金额必须是数字')
      return
    }
    if(numerValue<0){
      setTimeout(()=>{
        placement.searchParams[prop]=''
      },500)
      ElMessage.warning('金额必须大于等于零')
      return
    }
    // 开始金额大于结束金额 就不查询
    if(placement.searchParams.max_amount &&
    placement.searchParams.min_amount &&
      parseFloat(placement.searchParams.min_amount) > placement.searchParams.max_amount){
      return 
    }
    placement.searchParams[prop]=numerValue || ''
    searchPlacement()
  }
  // 搜索项-判断开始金额是否大于结束金额
  const checkMoney=()=>{
    if(placement.searchParams.max_amount &&
    placement.searchParams.min_amount &&
    parseFloat(placement.searchParams.min_amount) > placement.searchParams.max_amount){
      ElMessage.warning('开始金额不能大于结束金额')
    }
  }
  // 切换日期 本月、上月、前月
  const changeDateType=(tabId)=>{
    if(placement.currentDateTab==tabId) return
    placement.currentDateTab=tabId
    if(tabId==1){
      // 本月指 本月初 至 今天
      placement.dateRange=[moment().subtract((tabId-1), 'months').startOf('month').format('YYYY-MM-DD'),
      moment(new Date()).format('YYYY-MM-DD')]
    }else{
      placement.dateRange=[moment().subtract((tabId-1), 'months').startOf('month').format('YYYY-MM-DD'),
      moment().subtract((tabId-1), 'months').endOf('month').format('YYYY-MM-DD')]
    }
  }

  // 切换每页的数量
  const changePageSize=(pageSize)=>{
    placement.searchParams.page_size = pageSize
    placementList()
  }
  const changePageNo = (pageNo)=>{
    placement.searchParams.current = pageNo
    placementList()
  }
  
  const placementExport=()=>{
    getIandPList({...placement.searchParams,is_export:1}).then(res=>{
      let fileName = type==1?'开票列表':'到款列表'
      downloadByFlow(res,'xlxs',fileName)
    })
  }
  
  return {
    data:placement,
    dateButtonData,
    placementList,
    sellerChange,
    searchPlacement,
    moneyChange,
    placementExport,
    changePageNo,
    changePageSize,
    checkMoney,
    changeDateType,
    serviceTypeArray
  }
}